/*
** Module   : AuthData.java
** Abstract : Storage for authentication data.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20130529 Created initial version.
*/

package com.goldencode.p2j.security;

/**
 * Storage of authentication data, as read from the remote side.
 */
public class AuthData
{
   /** The appserver name associated with the authenticated session. */
   private final String appServer;
   
   /** The identity of the authenticated session, in "processId/userId" form. */
   private final String identity;

   /**
    * Saves the appserver name and builds a new {@link #identity} based on the subject's ID and
    * type.
    * 
    * @param    isProcess
    *           <code>true</code> if it authenticated as a process.
    * @param    subjectId
    *           The subject's ID, a process or user name.
    * @param    appServer
    *           The appserver's name, may be <code>null</code>.
    */
   public AuthData(boolean isProcess, String subjectId, String appServer)
   {
      this.appServer = appServer;

      String processID = (isProcess ? subjectId : "");
      String userID = (isProcess ? "" : subjectId);
      this.identity = processID + "/" + userID;
   }

   /**
    * Get the {@link #identity}.
    * 
    * @return   See above.
    */
   public String getIdentity()
   {
      return identity;
   }

   /**
    * Get the {@link #appServer} name.
    * 
    * @return   See above.
    */
   public String getAppServer()
   {
      return appServer;
   }

   /**
    * Check if this has authenticated as an appserver.
    * 
    * @return   <code>true</code> if {@link #appServer} is not-null and not-empty.
    */
   public boolean isAppServer()
   {
      return appServer != null && appServer.length() > 0;
   }
}
